@@ -6,7 +6,7 @@
 Represents an HTML Color .
 """
 
-from .domwidget import LabeledWidget
+from .widget_description import DescriptionWidget
 from .valuewidget import ValueWidget
 from .widget import register
 from .widget_core import CoreWidget
@@ -14,12 +14,11 @@ from .trait_types import Color
 from traitlets import Unicode, Bool
 
 
-@register('Jupyter.ColorPicker')
-class ColorPicker(LabeledWidget, ValueWidget, CoreWidget):
-    value = Color('black').tag(sync=True)
-    concise = Bool().tag(sync=True)
+@register
+class ColorPicker(DescriptionWidget, ValueWidget, CoreWidget):
+    value = Color('black', help="The color value.").tag(sync=True)
+    concise = Bool(help="Display short version with just a color selector.").tag(sync=True)
+    disabled = Bool(False, help="Enable or disable user changes.").tag(sync=True)
 
-    _model_module = Unicode('jupyter-js-widgets').tag(sync=True)
-    _view_module = Unicode('jupyter-js-widgets').tag(sync=True)
     _view_name = Unicode('ColorPickerView').tag(sync=True)
     _model_name = Unicode('ColorPickerModel').tag(sync=True)
